@@ -11,6 +11,7 @@
 # under the License.
 
 import sys
+import warnings
 
 from cliff import app
 from cliff import commandmanager
@@ -23,17 +24,21 @@ class StestrCLI(app.App):
 
     def __init__(self):
         super(StestrCLI, self).__init__(
-            description='stestr application',
+            description="A parallel Python test runner built around subunit",
             version=__version__,
             command_manager=commandmanager.CommandManager('stestr.cm'),
             deferred_help=True,
             )
 
     def initialize_app(self, argv):
+        self.options.debug = True
         self.LOG.debug('initialize_app')
 
     def prepare_to_run_command(self, cmd):
         self.LOG.debug('prepare_to_run_command %s', cmd.__class__.__name__)
+        group_regex = '([^\.]*\.)*' \
+            if cmd.app_args.parallel_class else cmd.app_args.group_regex
+        cmd.app_args.group_regex = group_regex
 
     def clean_up(self, cmd, result, err):
         self.LOG.debug('clean_up %s', cmd.__class__.__name__)
@@ -92,11 +97,23 @@ class StestrCLI(app.App):
                                  " together in the stestr scheduler. If "
                                  "both this and the corresponding config file "
                                  "option are set this value will be used.")
+        parser.add_argument('--parallel-class', '-p',
+                            action='store_true',
+                            default=False,
+                            help="Set the flag to group tests by class. NOTE: "
+                                 "This flag takes priority over the "
+                                 "`--group-regex` option even if it's set.")
 
         return parser
 
 
 def main(argv=sys.argv[1:]):
+    if sys.version_info[:2] == (2, 7):
+        msg = (
+            "Python 2.7 will reach the end of its life on January 1st, 2020. "
+            "Support for using python 2.7 with stestr will be removed in the "
+            "3.0.0 release in early 2020")
+        warnings.warn(msg, DeprecationWarning, stacklevel=2)
     cli = StestrCLI()
     return cli.run(argv)
 
